#include <windows.h>
#include "segmentdisplay.h"

DWORD selectionPin[4] = {SELECTION_SEGMENT_0, SELECTION_SEGMENT_1, SELECTION_SEGMENT_2, SELECTION_SEGMENT_3};
DWORD dataPin[8] = {PIN_A, PIN_B, PIN_C, PIN_D, PIN_E, PIN_F, PIN_G, PIN_DOT};
DWORD displayPattern[11] = {0x3F, 0x06, 0x5B, 0x4F, 0x66, 0x6D, 0x7D, 0x07, 0x7F, 0x6F};
volatile BOOL threadExit = FALSE;

BOOL SendSegmentData(BYTE displayValue);

//******************************************************************************
/// Sends display value on data pins.
/// @param[in]   displayValue    Data to be displayed.
/// @retval      TRUE            Success.
/// @retval      FALSE           Failure.
BOOL SendSegmentData(BYTE displayValue)
{
    char count = 0;
    /// Input parameter check.
    if (displayValue > 9)
    {
        return FALSE;
    }
    for (count = 0; count < 8; count++)
    {
        SetPinLevel(dataPin[count], ((displayPattern[displayValue] >> count) & 0x01));
    }   
    return TRUE;
}

//******************************************************************************
/// Configures GPIOs, used as input and output.
void SegmentPinConfig(void)
{
    char count = 0;
    BOOL returnValue = 0;

    /// Configures segment data pin as output.
    for (count = 0; count < 8; count++)
    {
        returnValue = SetPinAltFn(dataPin[count], (DWORD)GPIO, DIR_OUT);
        SetPinLevel(dataPin[count], FALSE);
    }
    /// Configures selection pin as output.
    for (count = 0; count < 4; count++)
    {
        returnValue = SetPinAltFn(selectionPin[count], (DWORD)GPIO, DIR_OUT);
        SetPinLevel(selectionPin[count], !SELECTION_PIN_LOGIC);
    }
}

//******************************************************************************
/// Displays data on seven segment.
/// @param[in]   digit      Digit array to be displayed.
void SegmentDisplay(DWORD *digit)
{
    DWORD selection = 0; 
	DWORD count = 0;
    while (threadExit == FALSE)
    {
        /// Sets all selection pins HIGH.
        SetPinLevel(SELECTION_SEGMENT_0, !SELECTION_PIN_LOGIC);
        SetPinLevel(SELECTION_SEGMENT_1, !SELECTION_PIN_LOGIC);
        SetPinLevel(SELECTION_SEGMENT_2, !SELECTION_PIN_LOGIC);
        SetPinLevel(SELECTION_SEGMENT_3, !SELECTION_PIN_LOGIC);
        SendSegmentData((BYTE)digit[selection]);
        /// Sets a particular selection pin.
        SetPinLevel(selectionPin[selection], SELECTION_PIN_LOGIC);
        if (selection >= 3)
		{
			selection = 0;
		}
        else
		{
			selection++;
		}
        Sleep(5);
    }
	/// Configures all segment pins LOW before thread exit.
    for (count = 0; count < 4; count++)
    {
        SetPinLevel(selectionPin[count], !SELECTION_PIN_LOGIC);
    }
}
 